.. :changelog:

History
-------

0.1.1 (2016-05-30)
++++++++++++++++++

* Allow property override.
* Add width and height property for open graph image.
* Prevent indexing unwanted domains.


0.1.0 (2016-05-24)
++++++++++++++++++

* First release on PyPI.
